@@ -9,6 +9,10 @@ class Theme(Feature):
 
         self.theme_name = name
 
+    def get_required_packages(self, cls):
+        return ('django-sekizai',)
+
+
     def load_theme(self, cls):
 
         from cratis.utils.themes import load_theme
