@@ -3,9 +3,12 @@ Default settings for cratis project
 """
 import logging
 import os
+import pywizard.api as pw
 
 from configurations import Configuration, values
 import sys
+from pywizard.context import Context
+from pywizard.cli import yn_choice
 
 
 class Common(Configuration):
@@ -34,21 +37,40 @@ class Common(Configuration):
 
         cls.load_features()
 
-        if len(sys.argv) == 2 and sys.argv[1] == '--requirements':
-
-            all_requirements = []
+        ctx = Context()
 
+        with pw.resource_set(ctx, name='main'):
             for feature in cls.FEATURES:
                 requirements = []
                 for req in feature.get_required_packages(cls):
-                    if not req in all_requirements:
-                        requirements.append(req)
-                        all_requirements.append(req)
+                    requirements.append(req)
 
                 if requirements:
-                    print('# %s\n%s\n' % (feature.__class__.__name__, '\n'.join(requirements)))
+                    ctx.apply(
+                        pw.pip_package(*requirements)
+                    )
 
-            exit()
+        changes = ctx.changeset()
+
+        if changes.needed():
+
+            if len(sys.argv) == 2 and sys.argv[1] == '--requirements':
+                print('\nChanges to be applied:\n')
+                for item in changes.items:
+                    print('\t - %s' % item.description)
+
+                changes.commit()
+
+                exit(0)
+
+            else:
+                print('\nSome required packages are not installed:\n')
+                for item in changes.items:
+                    print('\t - %s' % item.description)
+
+                print 'Execute "cratis --requirements" to install those'
+
+                exit(1)
 
 
     # Build paths inside the project like this: os.path.join(BASE_DIR, ...)
